@@ -188,7 +188,39 @@ class file:
             # 处理调用栈不足的异常（极少发生）
             return None
 
+    @staticmethod
+    def getFileSize(file_path,size_name='B',precision=2):
+        total_size = 0
+        allow_size_name = ("B", "KB", "MB", "GB", "TB")
+        if size_name not in allow_size_name:
+            raise Exception('getFileSize.size_name need in %s' % str(allow_size_name))
+        if not os.path.exists(file_path):
+            raise Exception(f"File or path not exists: {file_path}")
+        """获取单个文件的大小（字节）"""
+        if os.path.isfile(file_path):
+            total_size = os.path.getsize(file_path)
+        """递归计算目录的总大小（字节）"""
+        if os.path.isdir(file_path):
+            for root, dirs, files in os.walk(file_path):
+                for one_file in files:
+                    sub_file_path = os.path.join(root, one_file)
+                    try:
+                        total_size += os.path.getsize(sub_file_path)
+                    except PermissionError:
+                        print(f"No Permission: {sub_file_path}，passed")
+        if size_name == 'B':
+            pass
+        elif size_name == 'KB':
+            total_size = round(total_size/1024,precision)
+        elif size_name == 'MB':
+            total_size = round(total_size/1024/1024,precision)
+        elif size_name == 'GB':
+            total_size = round(total_size/1024/1024/1024,precision)
+        elif size_name == 'TB':
+            total_size = round(total_size/1024/1024/1024/1024,precision)
+        return total_size
+
 
 if __name__ == '__main__':
     # file.writeTxtFileAppendMode('a.log',content="sdfsdf\nsdfsd好的f\na\n")
-    print(file.getCurrentFilePath())
+    print(file.getFileSize('D:\code\myPythonPackages\jyhelper\dist',size_name='KB',precision=4))
